@@ -19,7 +19,7 @@ system = {
         'score': 2.0
     },
 
-    '`Do you have any kids?`'
+    '`So by the way, I am curious, do you have any kids?`'
     '#GSRET(default_start)': {
         'state': 'ask_user_kids',
 
@@ -375,6 +375,13 @@ exit = {
 user = {
     'state': 'user',
 
+    '[i, #NEGATION, have, #ONT(child)]'
+    '#SET($has_kids=False)': {
+
+        '`Oh I must have misheard you. `'
+        '#GRET(baby, want_kids_q)': 'want_kids_q'
+    },
+
     '{'
     '[who,your,family],'
     '[who,#LEM(create,develop,make,construct,build),you],'
@@ -470,7 +477,8 @@ for trans in transitions:
 
 baby.load_transitions(exit)
 baby.load_global_nlu(user, 10.0)
-baby.load_update_rules(rules)
+baby.load_update_rules(rules, score=999999999)
 
 if __name__ == '__main__':
+    baby.vars()['is_adult'] = 'True'
     baby.run(debugging=True)
\ No newline at end of file
