@@ -21,7 +21,7 @@ activity = {
     },
 
     "#GATE {" 
-    "[#ONT(not), {talk, talking, discuss, discussing, share, sharing, tell, say}]," 
+    "[not, {talk, talking, discuss, discussing, share, sharing, tell, say}]," 
     "[none,your,business]," 
     "[!{[!that,is],thats},private]" 
     "}":{
@@ -31,43 +31,44 @@ activity = {
     },
 
     # chores
-    '#GATE [#NOT(#ONT(not)),$chore=#ONT(chore)]': {
+    '#GATE [#NOT(not),$chore=#ONT(chore)]': {
         '"Oh, you did some chores? '
         'Now that we have all of this time on our hands, '
         'I can imagine it would be nice to tidy up!"': 'exit_activity'
     },
 
     # errands
-    '#GATE [#NOT(#ONT(not)),{#EXP(travel),#LEM(do)},$errand_dest=#ONT(errand)]': {
+    '#GATE [#NOT(not),{#EXP(travel),#LEM(do)},$errand_dest=#ONT(errand)]': {
         'score': 2.0,
         '[!"You know, it may not be the most exciting thing, but '
-        'I bet you are glad to be done with that errand for now."]':
+        'I bet you are glad to be done with that errand for now."]'
+        '#GSRET(exit_activity)':
         {
             'error': {
                 '"Well, okay. I just know that a lot of people are usually happy to be done with errands. '
                 'Anyways, "': 'exit_activity'
             },
-            "{#AGREE,[!{[!i,am],im},#NOT(#ONT(not))],[im,#NOT(#ONT(not)),#EXP(happy)]}": {
+            "{#AGREE,[!{[!i,am],im},#NOT(not)],[im,#NOT(not),#EXP(happy)]}": {
                 '"Great! Well, hopefully we can find something interesting to talk about to '
                 'spice up your day, something more exciting than errands. "': 'exit_activity'
             },
 
             "{"
-            "[i,#NOT(#ONT(not)),#EXP(enjoy),{it,that,#LEM(chore),#ONT(errand)}],"
-            "[{it,its,that,#LEM(chore),#ONT(errand),they},#NOT(#ONT(not)),{#EXP(fun),#EXP(break)}]"
+            "[i,#NOT(not),#EXP(enjoy),{it,that,#LEM(chore),#ONT(errand)}],"
+            "[{it,its,that,#LEM(chore),#ONT(errand),they},#NOT(not),{#EXP(fun),#EXP(break)}]"
             "}": {
                 '[!"You enjoy doing errands? I was not really expecting that! '
                 'Let\'s try to continue your pleasant day. "]': 'exit_activity'
             },
 
-            "{#DISAGREE,[!{[!i,am],im},#ONT(not)],[im,#ONT(not),#EXP(happy)]}": {
+            "{#DISAGREE,[!{[!i,am],im},not],[im,not,#EXP(happy)]}": {
                 '"I think I heard you say you are not glad to be done with your errands? Well, I am glad '
                 'they seem to bring you some sort of joy. "': 'exit_activity'
             },
 
             "{"
-            "[i,#ONT(not),#EXP(enjoy),{it,that,chore,#ONT(errand)}],"
-            "[{it,its,that,#LEM(chore),#ONT(errand),they},#ONT(not),{#EXP(fun),#EXP(break)}],"
+            "[i,not,#EXP(enjoy),{it,that,chore,#ONT(errand)}],"
+            "[{it,its,that,#LEM(chore),#ONT(errand),they},not,{#EXP(fun),#EXP(break)}],"
             "[{#EXP(annoy),#EXP(hate)}]"
             "}": {
                 '[!"Yeah, errands can be a bit annoying, but you have to do them at some point, unfortunately. '
@@ -78,14 +79,16 @@ activity = {
     },
 
     # homework
-    '#GATE [#NOT(#ONT(not)),$homework=#EXP(homework)]': {
+    '#GATE [#NOT(not),$homework=#EXP(homework)]': {
         'score': 3.0,
-        '[!"You have some " $homework "? That is a pretty good use of your time, keep up the good work! I know it might be kind of hard to stay motivated due to the current situation. Are you taking a break now?"]':
+        '[!"You have some " $homework "? That is a pretty good use of your time, keep up the good work! '
+        'I know it might be kind of hard to stay motivated due to the current situation. Are you taking a break now?"]'
+        '#GSRET(exit_activity)':
         {
-            "{#AGREE,[!{[!i,am],im},#NOT(#ONT(not))]}":{
+            "{#AGREE,[!{[!i,am],im},#NOT(not)]}":{
                 '"Awesome! I am glad you have decided to include me in your break. "': 'exit_activity'
             },
-            "{#DISAGREE,[!{[!i,am],im},#ONT(not)]}":{
+            "{#DISAGREE,[!{[!i,am],im},not]}":{
                 '"You aren\'t really taking a break, but you are talking to me right now? '
                 'Well, I am glad to be talking to you. "': 'exit_activity'
             },
@@ -110,31 +113,32 @@ activity = {
     },
 
     #homework
-    '#GATE [#NOT(#ONT(not)),#LEM(complete,finish),$homework=#EXP(homework)]': {
-        '"It sounds like you finished some work. You should be proud! It feels good to be done, doesn\'t it?"':{
+    '#GATE [#NOT(not),#LEM(complete,finish),$homework=#EXP(homework)]': {
+        '"It sounds like you finished some work. You should be proud! It feels good to be done, doesn\'t it?"'
+        '#GSRET(exit_activity)':{
             'error': {
                 '"I see. It does seem like a lot of people are so relieved when they are done with some work. "': 'exit_activity'
             },
-            "{#AGREE,[!{[!i,am],im},#NOT(#ONT(not))],[im,#NOT(#ONT(not)),#EXP(happy)]}": {
+            "{#AGREE,[!{[!i,am],im},#NOT(not)],[im,#NOT(not),#EXP(happy)]}": {
                 '"I knew it! Well, hopefully we can find something interesting to talk about to '
                 'spice up your day, other than your homework. "': 'exit_activity'
             },
 
             "{"
-            "[i,#NOT(#ONT(not)),#EXP(enjoy),{it,that,#EXP(homework)}],"
-            "[{it,its,that,they,#EXP(homework)},#NOT(#ONT(not)),{#EXP(fun),#EXP(break)}]"
+            "[i,#NOT(not),#EXP(enjoy),{it,that,#EXP(homework)}],"
+            "[{it,its,that,they,#EXP(homework)},#NOT(not),{#EXP(fun),#EXP(break)}]"
             "}": {
                 '"You enjoy doing some schoolwork? Yeah, I guess depending on the topic, it could be cool!"': 'exit_activity'
             },
 
-            "{#DISAGREE,[!{[!i,am],im},#ONT(not)],[im,#ONT(not),#EXP(happy)]}": {
+            "{#DISAGREE,[!{[!i,am],im},not],[im,not,#EXP(happy)]}": {
                 '"I think I heard you say you are not glad to be done with your work? Either you enjoy it or '
                 'you still have more to do. Regardless, I am happy to be talking to you now. So, "': 'exit_activity'
             },
 
             "{"
-            "[i,#ONT(not),#EXP(enjoy),{it,that,#EXP(homework)}],"
-            "[{it,its,that,they,#EXP(homework)},#ONT(not),{#EXP(fun),#EXP(break)}],"
+            "[i,not,#EXP(enjoy),{it,that,#EXP(homework)}],"
+            "[{it,its,that,they,#EXP(homework)},not,{#EXP(fun),#EXP(break)}],"
             "[#EXP(annoy)]"
             "}": {
                 '"Yeah, I think most people find schoolwork to be annoying, but you have to do them at some point, unfortunately. "': 'exit_activity'
@@ -152,7 +156,7 @@ activity = {
     },
 
     # school
-    '#GATE [#NOT(#ONT(not)),{#EXP(travel),#LEM(attend,do,have)},{school,#EXP(class)}]': {
+    '#GATE [#NOT(not),{#EXP(travel),#LEM(attend,do,have)},{school,#EXP(class)}]': {
         'score': 2.0,
         '"Attending class is pretty different at the moment, but I am glad to hear that they are at least '
         'still working for you. "': 'exit_activity'
@@ -164,7 +168,7 @@ activity = {
     },
 
     # work
-    '[#NOT(#ONT(not)),{[{#EXP(travel),#LEM(do,have)},#LEM(work,job)],#LEM(work)}]': {
+    '[#NOT(not),{[{#EXP(travel),#LEM(do,have)},#LEM(work,job)],#LEM(work)}]': {
         'score': 2.0,
         '"I am glad you are able to keep working in spite of everything that is going on. "': 'exit_activity'
         # '#GATE(worklifev:None) #SET($worklifev=True) "I\'m glad you are able to keep working in spite of everything that is going on. "': {
@@ -179,7 +183,7 @@ activity = {
     },
 
     # nothing
-    '{#IDK,[{nothing,none,have not decided,havent decided, up in the air, undecided, not much,[#ONT(not),anything]}]} '
+    '{#IDK,[{nothing,none,have not decided,havent decided, up in the air, undecided, not much,[not,anything]}]} '
     '#SET($no_activity=True)':{
         '{"Yeah, sometimes it is hard to decide what to do.",'
         '"Sure, I know the feeling of not really doing too much."}': {
@@ -189,7 +193,7 @@ activity = {
     },
 
     # relax
-    '[#NOT(#ONT(not)),{relax,chill,fun,enjoy,[#LEM(take),break]}] '
+    '[#NOT(not),{relax,chill,fun,enjoy,[#LEM(take),break]}] '
     '#SET($no_activity=True)':{
         '{"Its always good to take some time to relax.",'
         '"You can never underappreciate the value of taking some time for yourself."}':  {
@@ -243,17 +247,18 @@ activity = {
     },
 
     # talking to somebody
-    '#GATE [#NOT(#ONT(not)),#LEM(see,talk,chat,call),$contact=#ONT(related_person)]': {
+    '#GATE [#NOT(not),#LEM(see,talk,chat,call),$contact=#ONT(related_person)]': {
         '[!"It is good to hear that you are keeping in touch with the people in your life. '
-        'Are you close to your"$contact"?"]':{
+        'Are you close to your"$contact"?"]'
+        '#GSRET(exit_activity)':{
             'error': {
                 '"Okay. Well, I hope you are able to stay connected with everyone you want to, even in these weird times. "': 'exit_activity'
             },
-            "{#AGREE,[!{[!i,am],im},#NOT(#ONT(not))],[#NOT(#ONT(not)),{#LEM(close),intimate,inseparable,best}]}": {
+            "{#AGREE,[!{[!i,am],im},#NOT(not)],[#NOT(not),{#LEM(close),intimate,inseparable,best}]}": {
                 '"Wow, you sound like you are really close to them. I am glad to hear that. "': 'exit_activity'
             },
 
-            "{#DISAGREE,[!{[!i,am],im},#ONT(not)],[#ONT(not),{#LEM(close),intimate,inseparable,best}]}": {
+            "{#DISAGREE,[!{[!i,am],im},not],[not,{#LEM(close),intimate,inseparable,best}]}": {
                 '"You aren\'t that close to them? Well, I hope you are able to stay connected with the other people '
                 'who are important in your life. "': 'exit_activity'
             }
@@ -261,17 +266,18 @@ activity = {
     },
 
     # play with somebody
-    '#GATE [#NOT(#ONT(not)),#LEM(play),with,$contact=#ONT(related_person)]': {
+    '#GATE [#NOT(not),#LEM(play),with,$contact=#ONT(related_person)]': {
         '[!"It is good to hear that you are spending time with the people in your life. '
-        'Are you close to your"$contact"?"]': {
+        'Are you close to your"$contact"?"]'
+        '#GSRET(exit_activity)': {
             'error': {
                 '[!"Okay. Well, playing with your" $contact "is a good way to pass the time and have some fun, I think."]': 'exit_activity'
             },
-            "{#AGREE,[!{[!i,am],im},#NOT(#ONT(not))],[#NOT(#ONT(not)),{#LEM(close),intimate,inseparable,best}]}": {
+            "{#AGREE,[!{[!i,am],im},#NOT(not)],[#NOT(not),{#LEM(close),intimate,inseparable,best}]}": {
                 '"Wow, you sound like you are really close to them. I am glad to hear that. "': 'exit_activity'
             },
 
-            "{#DISAGREE,[!{[!i,am],im},#ONT(not)],[#ONT(not),{#LEM(close),intimate,inseparable,best}]}": {
+            "{#DISAGREE,[!{[!i,am],im},not],[not,{#LEM(close),intimate,inseparable,best}]}": {
                 '"You aren\'t that close to them? Well, I hope you are able to spend time with the other people '
                 'who are important in your life, too. "': 'exit_activity'
             }
@@ -279,17 +285,18 @@ activity = {
     },
 
     # play with a pet
-    '#GATE [#NOT(#ONT(not)),#LEM(play),with,$animal=#ONT(animal)]': {
+    '#GATE [#NOT(not),#LEM(play),with,$animal=#ONT(_animals)]': {
         '[!"It is good to hear that you are spending time with your animals. '
-        'Do you play a lot with your "$animal"?"]': {
+        'Do you play a lot with your "$animal"?"]'
+        '#GSRET(exit_activity)': {
             'error': {
                 '[!"Okay. Well, playing with your" $animal "is a good way to pass the time and have some fun, I think."]': 'exit_activity'
             },
-            "{#AGREE,[!{[!i,am],im},#NOT(#ONT(not))],[#NOT(#ONT(not)),{#LEM(close),intimate,inseparable,best}]}": {
+            "{#AGREE,[!{[!i,am],im},#NOT(not)],[#NOT(not),{#LEM(close),intimate,inseparable,best}]}": {
                 '"Wow, you sound like you really care for them. I am glad to hear that. "': 'exit_activity'
             },
 
-            "{#DISAGREE,[!{[!i,am],im},#ONT(not)],[#ONT(not),{#LEM(close),intimate,inseparable,best}]}": {
+            "{#DISAGREE,[!{[!i,am],im},not],[not,{#LEM(close),intimate,inseparable,best}]}": {
                 '"You don\'t spend that much time playing with your " $animal "? Well, it is always good to give '
                 'them some attention when you can."': 'exit_activity'
             }
@@ -297,38 +304,38 @@ activity = {
     },
 
     # going somewhere indoors
-    '#GATE [#NOT(#ONT(not)),#EXP(travel),$dest=#ONT(indoor_destination)]': {
+    '#GATE [#NOT(not),#EXP(travel),$dest=#ONT(indoor_destination)]': {
         'score': 4.0,
         '` `': 'exit_activity'
     },
 
     # going somewhere outside
-    '#GATE [#NOT(#ONT(not)),{#EXP(travel),#LEM(play)},$dest=#ONT(outdoor_destination)]': {
+    '#GATE [#NOT(not),{#EXP(travel),#LEM(play)},$dest=#ONT(outdoor_destination)]': {
         'score': 4.0,
         '[!"It is nice to get out of the house and spend some time outdoors in the "$dest", with everything '
         'that is going on. I hope you enjoyed yourself and are staying safe. "]': 'exit_activity'
     },
 
     # play outside
-    '#GATE [#NOT(#ONT(not)),{#EXP(travel),#LEM(play)},{outdoors,outdoor,outside}]': {
+    '#GATE [#NOT(not),{#EXP(travel),#LEM(play)},{outdoors,outdoor,outside}]': {
         'score': 4.0,
         '[!"It is nice to get out of the house and spend some time outdoors, with everything '
         'that is going on. I hope you enjoyed yourself and are staying safe. "]': 'exit_activity'
     },
 
     # play inside
-    '#GATE [#NOT(#ONT(not)),{#EXP(travel),#LEM(play)},{indoor,indoors,inside}]': {
+    '#GATE [#NOT(not),{#EXP(travel),#LEM(play)},{indoor,indoors,inside}]': {
         'score': 4.0,
         '[!"I hope you enjoyed your indoor activities, it is good to keep yourself entertained! "]': 'exit_activity'
     },
 
     # playing with child toys
-    '#GATE [#NOT(#ONT(not)),#LEM(play),{game,games,house,home,dolls,doll,barbie,barbies,toy,toys}]': {
+    '#GATE [#NOT(not),#LEM(play),{game,games,house,home,dolls,doll,barbie,barbies,toy,toys}]': {
         '[!"I hope you enjoyed playing with your toys, it is good to keep yourself entertained! "]': 'exit_activity'
     },
 
     # watching tv
-    '#GATE [#NOT(#ONT(not)),$watching={#EXP(television),#EXP(hbo),#LEM(movie,channel,show,cartoon),youtube,netflix,hulu}]': {
+    '#GATE [#NOT(not),$watching={#EXP(television),#EXP(hbo),#LEM(movie,channel,show,cartoon),youtube,netflix,hulu}]': {
             '[!"Oh, "$watching"? That seems to be a good one. Watching movies and shows is always so fun, and '
             'an easy way to relax. "]': 'exit_activity'
         },
@@ -336,7 +343,8 @@ activity = {
     # art
     '#GATE [$art_medium=#ONT(_artistic)]': {
 
-        '`Oh you\'re artistic, that\'s cool! What kinds of things do you make?`': {
+        '`Oh you\'re artistic, that\'s cool! What kinds of things do you make?`'
+        '#GSRET(exit_activity)': {
 
             'error': {
 
@@ -346,59 +354,64 @@ activity = {
     },
 
     # playing video games
-    '#GATE [#NOT(#ONT(not)),#LEM(play),$console=#ONT(game_console)]': {
+    '#GATE [#NOT(not),#LEM(play),$console=#ONT(game_console)]': {
         '[!"Oh, cool! You have a "$console"? I bet you are having a lot of fun playing video games to pass '
-        'the time. Are you playing them more than usual nowadays?"]': {
+        'the time. Are you playing them more than usual nowadays?"]'
+        '#GSRET(exit_activity)': {
             'error': {
                 '"I see. Video games do seem to be one popular activity to relax and have fun for a lot '
                 'of people. "': 'exit_activity'
             },
-            "{#AGREE,[!{[!i,am],im},#NOT(#ONT(not))],[#NOT(#ONT(not)),{more,a lot,#EXP(frequently)}]}": {
+            "{#AGREE,[!{[!i,am],im},#NOT(not)],[#NOT(not),{more,a lot,#EXP(frequently)}]}": {
                 '"That makes sense. They are one easy way to keep yourself busy at home. "': 'exit_activity'
             },
 
-            "{#DISAGREE,[!{[!i,am],im},#ONT(not)],[#ONT(not),{more,a lot,#EXP(frequently)}]}": {
+            "{#DISAGREE,[!{[!i,am],im},not],[not,{more,a lot,#EXP(frequently)}]}": {
                 '"Well, I am glad you are able to enjoy playing them at least some of the time. "': 'exit_activity'
             }
         }
     },
 
     # playing video games
-    '#GATE [#NOT(#ONT(not)),#LEM(play),{#ONT(vgames),[!video, #LEM(game)]}]': {
+    '#GATE [#NOT(not),#LEM(play),{#ONT(vgames),[!video, #LEM(game)]}]': {
+        'score': 1.1,
+
         '[!"Oh, cool! I bet you are having a lot of fun playing video games to pass '
-        'the time. Are you playing them more than usual nowadays?"]': {
+        'the time. Are you playing them more than usual nowadays?"]'
+        '#GSRET(exit_activity)': {
             'error': {
                 '"I see. Video games do seem to be one popular activity to relax and have fun for a lot '
                 'of people. "': 'exit_activity'
             },
-            "{#AGREE,[!{[!i,am],im},#NOT(#ONT(not))],[#NOT(#ONT(not)),{more,a lot,#EXP(frequently)}]}": {
+            "{#AGREE,[!{[!i,am],im},#NOT(not)],[#NOT(not),{more,a lot,#EXP(frequently)}]}": {
                 '"That makes sense. They are one easy way to keep yourself busy at home. "': 'exit_activity'
             },
 
-            "{#DISAGREE,[!{[!i,am],im},#ONT(not)],[#ONT(not),{more,a lot,#EXP(frequently)}]}": {
+            "{#DISAGREE,[!{[!i,am],im},not],[not,{more,a lot,#EXP(frequently)}]}": {
                 '"Well, I am glad you are able to enjoy playing them at least some of the time. "': 'exit_activity'
             }
         }
     },
 
     # sports or exercise
-    '#GATE [#NOT(#ONT(not)),{$exercise={#EXP(exercise),[!#LEM(work),out],#ONT(outdoor_exercise,indoor_exercise)},[#LEM(play),$exercise=#ONT(sports)]}]':{
+    '#GATE [#NOT(not),{$exercise={#EXP(exercise),[!#LEM(work),out],#ONT(outdoor_exercise,indoor_exercise)},[#LEM(play),$exercise=#ONT(sports)]}]':{
             'score':3.0,
             '[!"Oh, "$exercise"? It seems like a lot of people are spending this extra time at home getting into a '
-            'good exercise routine. Is that something you are trying to do too?"]':{
+            'good exercise routine. Is that something you are trying to do too?"]'
+            '#GSRET(exit_activity)':{
                 'error': {
                     '"Ok, sure. Any exercise is better than none!"': 'exit_activity'
                 },
                 "{"
-                "#AGREE,[!{[!i,am],im},#NOT(#ONT(not))],"
-                "[#NOT(#ONT(not)),{it,that,some,{#EXP(exercise),[!#LEM(work),out],#ONT(outdoor_exercise,indoor_exercise,sports)}},{more,a lot,#EXP(frequently)}]"
+                "#AGREE,[!{[!i,am],im},#NOT(not)],"
+                "[#NOT(not),{it,that,some,{#EXP(exercise),[!#LEM(work),out],#ONT(outdoor_exercise,indoor_exercise,sports)}},{more,a lot,#EXP(frequently)}]"
                 "}": {
                     '"Wow, I admire you for doing that. It is important to stay healthy in times like this, for sure. "': 'exit_activity'
                 },
 
                 "{"
-                "#DISAGREE,[!{[!i,am],im},#ONT(not)],"
-                "[#ONT(not),{it,that,some,{#EXP(exercise),[!#LEM(work),out],#ONT(outdoor_exercise,indoor_exercise,sports)}},{more,a lot,#EXP(frequently)}]"
+                "#DISAGREE,[!{[!i,am],im},not],"
+                "[not,{it,that,some,{#EXP(exercise),[!#LEM(work),out],#ONT(outdoor_exercise,indoor_exercise,sports)}},{more,a lot,#EXP(frequently)}]"
                 "}": {
                     '"Well, you never know. You just might get into a really good routine anyways, without even trying. "': 'exit_activity'
                 },
@@ -422,15 +435,24 @@ exit_activity = {
 
 hobby_flow = {
     'state': 'start',
-    'enter': '#GCOM(hobby) #GOAL(hobby) #GATE',
+    'enter': '#GCOM(hobby) #GOAL(hobby) #IF($entered_hobby!=True) #GATE',
 
-    '`What\'s a hobby you have that you really enjoy?`': {
+    '`What\'s a hobby you have that you really enjoy?`'
+    '#GSRET(hobby_default_start)': {
         'state': 'hobby_question',
 
         '/.*/ #GSRET(hobby_followup)': {
             'state': 'activity',
             'hop': 'True'
         }
+    },
+
+    '#DEFAULT':{
+        'state': 'hobby_default_start',
+        'hop': 'True',
+
+        '`So, I think I misheard what you said earlier. What is your favorite hobby to do?`':
+            'hobby_question'
     }
 }
 
@@ -439,6 +461,7 @@ hobby_followup = {
     'enter': '',
 
     '`What do you like so much about this hobby?`'
+    '#GSRET(exit)'
     '#IF($no_activity!=True)': {
 
         '#IDK': {
@@ -457,7 +480,7 @@ hobby_followup = {
 
 reading = {
     'state': 'reading',
-    'enter': '#GATE #GCOM(reading) #GOAL(reading)',
+    'enter': '#GATE #GCOM(hobby) #GOAL(hobby)',
 
     '`For me personally, I\'ve been taking the time to read a little bit every day. '
     'It was slow going at first, but now I really enjoy it.`'
@@ -484,10 +507,10 @@ reading = {
         'error': {
             'state': 'share_hobbit',
 
-            '`I\'ve been reading the hobbit. I really like Bilbo. '
+            '`I\'ve only been reading the hobbit for a little bit now. I really like Bilbo. '
             'I feel like I can relate a lot to someone who gets swept up '
             'in an adventure that\'s exhilarating, but where they are forced to '
-            'struggle and learn to overcome tough new challenges.`'
+            'learn to overcome tough new challenges.`'
             '#GSRET(reciprocity)':{
 
                 '[why]': {
@@ -509,19 +532,32 @@ reading = {
 
 reciprocity = {
     'state': 'reciprocity',
-    'enter': '#GATE #GCOM(reading) #GOAL(reading)',
+    'enter': '#GATE #GCOM(hobby) #GOAL(hobby)',
 
-    '`Do you have a favorite book?`': {
+    '`Do you have a favorite book?`'
+    '#GSRET(exit)': {
 
         '{#DISAGREE,#IDK}': {
 
             '`I get you. Especially when I started to read, I felt like it was pretty '
             'boring at first, but now I like it.`'
-            '#GSRET(rexit)':
-                'rexit'
+            '#GSRET(exit)':
+                'exit'
+        },
+
+        '{[!i do -not],<#AGREE,#TOKLIMIT(1)>}': {
+            'state': 'user_fave_book_y',
+
+            '`I wonder if I have heard of it. What is it called?`'
+            '#GSRET(exit)':{
+                'state': 'user_fave_book_unx',
+
+                '#UNX': 'user_fave_book_reply'
+            }
         },
 
         '#UNX':{
+            'state': 'user_fave_book_reply',
 
             '`Cool! What do you like about it?`'
             '#GATE': {
@@ -531,9 +567,9 @@ reciprocity = {
 
                     '`Well I\'ll have to check it out. Maybe that will be the '
                     'second book I read once I\'m done with the hobbit!`'
-                    '#GSRET(rexit)': {
+                    '#GSRET(exit)': {
 
-                        '#UNX': 'rexit'
+                        '#UNX': 'exit'
                     }
                 }
             },
@@ -543,20 +579,6 @@ reciprocity = {
     }
 }
 
-rexit = {
-    'state': 'rexit',
-
-    '#GCOM(reading)': {
-        'score': 0.0,
-        'state':'SYSTEM:root'
-    },
-
-    '#GCOM(reading) ` `': {
-        'score': 2.0,
-        'state': 'start'
-    }
-}
-
 ruser = {
     'state': 'user',
 
@@ -614,7 +636,8 @@ today_flow = {
     'state': 'today_flow',
     'enter': '#GCOM(today) #GOAL(today) #GATE',
 
-    '`So, what did you get up to today?`': {
+    '`So, what did you get up to today?`'
+    '#GSRET(exit)': {
         'state': 'today_question',
 
         '/.*/ #GSRET(exit)': {
@@ -638,12 +661,6 @@ user = {
     'state': 'user'
 }
 
-rules = {
-    '[{my, to, with} $with_clause=#ONT(related_person)]': '',
-    '#IF($with_clause!=None)': '#INC($to_clear)',
-    '#IF($to_clear>1)': '#SET($with_clause=None)'
-}
-
 hobby.load_transitions(activity, DialogueFlow.Speaker.USER)
 hobby.load_transitions(exit_activity)
 
@@ -652,13 +669,12 @@ hobby.load_transitions(hobby_followup)
 
 hobby.load_transitions(reading)
 hobby.load_transitions(reciprocity)
-hobby.load_transitions(rexit)
-hobby.load_global_nlu(ruser)
+hobby.load_global_nlu(ruser, 10.0)
 
 hobby.load_transitions(today_flow)
 
 hobby.load_transitions(exit)
-hobby.load_global_nlu(user)
+hobby.load_global_nlu(user, 10.0)
 
 
 if __name__ == '__main__':
