@@ -6,12 +6,12 @@ from emora._flows._central_knowledge import central_knowledge
 
 
 relationships = DialogueFlow('_local_start', kb=central_knowledge)
-relationships.add_system_transition('_local_start', 'start', '')
+relationships.add_system_transition('_local_start', 'dating', '')
 
 system = {
     'state': 'dating',
     'enter': '#GATE #GCOM(relationship) #GOAL(relationship)'
-             '#ALL($is_child=False,$relationship_status!=married,$relationship_status!=engaged,$entered_dating!=True)'
+             '#ALL($relationship_status!=married,$relationship_status!=engaged,$entered_dating!=True)'
              '#SET($entered_dating=True)',
 
     '#DEFAULT': {
@@ -593,6 +593,15 @@ exit = {
 user = {
     'state': 'user',
 
+    # i'm not married/in a relationship
+    '{'
+    '[i, #NEGATION, {married, in a relationship, have a boyfriend, have a girlfriend, dating, with anyone, have a spouse, have a partner}]'
+    '}': {
+
+        '`Oh I see, I must have misheard you.`'
+        '#GCLR': 'exit'
+    },
+
     #where did they get married,friend
     '[{location,venue,place,where},{they,their,friend,friends},{married,wedding}]':{
         'state': 'friend_wedding_loc_q',
@@ -848,4 +857,5 @@ relationships.load_global_nlu(user, 10.0)
 
 
 if __name__ == '__main__':
+    relationships.vars()['is_adult'] = 'True'
     relationships.run(debugging=True)
\ No newline at end of file
