@@ -9,7 +9,7 @@ school.add_system_transition('_local_start', 'start', '')
 
 system = {
     'state': 'start',
-    'enter': '#GATE #GCOM(school) #GOAL(school)',
+    'enter': '#GATE #GCOM(school) #GOAL(school) #IF($entered_school!=True)',
 
     '#DEFAULT':{
         'state': 'default_start',
@@ -202,7 +202,11 @@ system = {
 
             '`Oh, really? I am a student myself right now, and I have no idea what I want to do afterwards. `'
             '#GCOM(school)':
-                'worklife:start'
+                'worklife:start',
+
+
+            '#DEFAULT `Oh, really? I am a student myself right now, and I have no idea what I want to do afterwards. `':
+                'exit'
         },
 
         '[!-{like,dislike,hate,love,enjoy} [i,not, {a student,in school,[#LEM(take) class]}]]'
